import typescript from '@rollup/plugin-typescript';
import uglify from '@lopatnov/rollup-plugin-uglify';
import prettier from "rollup-plugin-prettier";
import copy from 'rollup-plugin-copy2'
import styles from "rollup-plugin-styles";
import replace from '@rollup/plugin-replace';
import { version, main, vendor, widgetName } from './package.json';
import zip from 'rollup-plugin-zip'

const production = !process.env.ROLLUP_WATCH;

export default {
  input: `src/${main}`,
  output: {
    dir: 'dist',
    format: 'amd',
    name: 'widget',
    sourcemap: true
  },
  sourceMap: "inline",
  plugins: [
    replace({
      __WIDGET__: `${vendor}_${widgetName}`,
      __VERSION__: version
    }),
    styles({
      mode: [
        "inject",
        { container: "body", singleTag: true, prepend: true, attributes: { id: "global" } },
      ],
    }),
  	copy({
      assets: [
        ['src/manifest.json', 'manifest.json'],
      	['src/i18n/ru.json', 'i18n/ru.json']
      ]
    }),
  	typescript({ module: "ESNext", lib:['dom', 'es2015'] }),
    (!production) ? null : prettier({
      tabWidth: 2,
      singleQuote: false,
      sourcemap: true,
    }),
  	(!production) ? null : uglify(),
    zip({
      file: 'widget.zip'
    })
  ],
  external: [
  	'underscore', 
    'Modal',
  	'jquery', 
  	'moment'
  ],
  paths: {
    "underscore": 'underscore',
    "jquery": 'jquery',
    "Modal": 'lib/components/base/modal',
    "moment": 'moment'
  }
};