/**
 * Главный модуль виджета
 * @module template/main
 * @author Gate <hello@amgate.ru>
 */

import { bind } from 'underscore';
import { Widget, Settings, System, Statuses } from './types/widget.types';
import { Application, Constants } from './types/global.types';
import './styles/default.scss';


declare const APP: Application;


/**
 * Widget template
 * @class Application
 * @author Gate <hello@amgate.ru>
 * @implements {Widget}
 * @see {@link https://www.amocrm.ru/developers/content/integrations/script_js} 
 */
export default class WidgetTemplate implements Widget {

	/**
	 * Внутренние параметры
	 * @readonly
	 * @type ApplicationSystem
	 */
	system?(): System

	/**
	 * Настройки
	 * @readonly
	 * @type Function(): ApplicationSettings
	 */
	get_settings?(): Settings

	/**
	 * Файлы локализации
	 * @readonly
	 * @type string
	 */
	i18n?(name: string): string

	/**
	 * Файлы локализации
	 * @readonly
	 * @type string
	 */
	set_status?(status: Statuses): void;

	/**
	 * Возвращает текущую версию из манифеста
	 * @readonly
	 * @type string
	 */
	get_version?(): string;

	/**
	 * Коллбеки
	 * @readonly
	 * @type Record<string, Function | Record<string, Function>>
	 */
	callbacks = {

		/**
		 * Модалка виджета в amoМаркет-е
		 * @async
		 * @returns {Promise<boolean>}
		 */
		settings: bind(async (): Promise<boolean> => {
			return true;
		}, this),

		/**
		 * Инициализация виджета
		 * @async
		 * @returns {Promise<boolean>}
		 */
		init: bind(async (): Promise<boolean> => {
			return true;
		}, this),

		/**
		 * Отрисовка интерфейса виджета
		 * @async
		 * @returns {Promise<boolean>}
		 */
		render: bind(async (): Promise<boolean> => {
			return true;
		}, this),

		/**
		 * @async
		 * @returns {Promise<boolean>}
		 */
		bind_actions: bind(async (): Promise<boolean> => {
            return true;
        }, this),

	}

	/**
	 * @constructor
	 * @returns {Widget}
	 */
	constructor() {
	    return this;
	}


}
